@@ -37,15 +37,24 @@ class DynaMindXML2Json:
 
             filter = n.find('Filter')
             if filter:
-                filter_view = [e.text.strip() for e in filter.findall("filter_view")]
-                attribtue_filter = [e.text.strip() if e.text else "" for e in filter.findall("attribtue_filter")]
-                spatial_filter = [e.text.strip() if e.text else "" for e in filter.findall("spatial_filter")]
+                try:
+                    filter_view = [e.text.strip() for e in filter.findall("view_name")]
+                except AttributeError:
+                    filter_view = []
+                try:
+                    attribtue_filter = [e.text.strip() if e.text else "" for e in filter.findall("attribtue_filter")]
+                except AttributeError:
+                    attribtue_filter = []
+                try:
+                    spatial_filter = [e.text.strip() if e.text else "" for e in filter.findall("spatial_filter")]
+                except AttributeError:
+                    spatial_filter = []
                 node_filter = {}
-                node_filter["filter_view"] = filter_view
+                node_filter["view_name"] = filter_view
                 node_filter["attribute_filter"] = attribtue_filter
                 node_filter["spatial_filter"] = spatial_filter
                 node["filter"] = node_filter
-                # print(node["name"], node_filter)
+
             group_uuids.add(node["group_uuid"])
             node["parameters"] = self._generate_parameters(n)
             self._nodes[n.find('UUID').get("value")] = node
